@@ -37,7 +37,7 @@ impl std::fmt::Debug for Show /* {{{ */ {
 } // }}}
 
 impl Show {
-	#[allow(dead_code)] // Used in tests
+	#[cfg(test)]
 	#[allow(clippy::too_many_arguments)] // Only a convenience function for tests; this is fine
 	pub(crate) fn new(imdb_id: u32, title: &str, is_adult: bool, start_year: u16, end_year: Option<u16>, runtime_minutes: Option<u16>, genres: &[&str], episodes: &[Episode]) -> Self /* {{{ */ {
 		Self{
@@ -86,6 +86,7 @@ pub struct Episode {
 	pub episode: u16,
 	pub imdb_id: u32,
 	pub title: String,
+	pub year: Option<u16>,
 	pub runtime_minutes: Option<u16>
 }
 
@@ -105,13 +106,14 @@ impl Ord for Episode /* {{{ */ {
 } // }}}
 
 impl Episode {
-	#[allow(dead_code)] // Used in tests
-	pub(crate) fn new(season: u16, episode: u16, imdb_id: u32, title: &str, runtime_minutes: Option<u16>) -> Self /* {{{ */ {
+	#[cfg(test)]
+	pub(crate) fn new(season: u16, episode: u16, imdb_id: u32, title: &str, year: Option<u16>, runtime_minutes: Option<u16>) -> Self /* {{{ */ {
 		Self{
 			season,
 			episode,
 			imdb_id,
 			title: String::from(title),
+			year,
 			runtime_minutes
 		}
 	} // }}}
@@ -129,6 +131,7 @@ impl Episode {
 				},
 				imdb_id: title.imdb_id,
 				title: title.primary_title,
+				year: title.start_year,
 				runtime_minutes: title.runtime_minutes
 			}),
 			_ => Err(Error::WrongMediaType(title.title_type.into(), "Episode"))
